IsIdentity

Trait IsIdentity 

pub trait IsIdentity {
    // Required method
    fn is_identity(&self) -> bool;
}
Trait for testing if a curve point is equivalent to the identity point.

Required Methods

fn is_identity(&self) -> bool

Return true if this element is the identity element of the curve.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> IsIdentity for T

Implement generic identity equality testing for a point representations which have constant-time equality testing and a defined identity constructor.