pub trait IsIdentity {
// Required method
fn is_identity(&self) -> bool;
}Expand description
Trait for testing if a curve point is equivalent to the identity point.
Required Methods
Sourcefn is_identity(&self) -> bool
fn is_identity(&self) -> bool
Return true if this element is the identity element of the curve.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<T> IsIdentity for Twhere
T: ConstantTimeEq + Identity,
Implement generic identity equality testing for a point representations which have constant-time equality testing and a defined identity constructor.